<?php
namespace FoodExpo\Admin\Classes;
/**
 * FoodExpo Admin Template
 *
 * @package     FoodExpo
 * @author      WPBucket
 * @copyright   2021 WPBucket
 * @license     GPL-2.0-or-later
 *
 *
 */

if( !defined( 'WPINC' ) ) {
    die;
}

if( !class_exists('Admin_Template') ) {

    class Admin_Template {

        private static $instance = null;

        private static $tabLists = [];

        function __construct() {
            self::template_content_area();
        }

        public static function getInstance() {
            if( self::$instance == null ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        /**
         * Admin Template Content Area
         *
         *
         */
    	private static function template_content_area() {
    		?>
        	<div class="foodexpo--body-wrapper">
                <div class="foodexpo--body-inner">
                    <form id="foodexpo--settings_from" action="" method="post">
                        <?php
                        // check if the user have submitted the settings
                        if ( isset( $_GET['settings-updated'] ) ) {
                        // add settings saved message with the class of "updated"
                        add_settings_error( 'foodexpo--messages', 'foodexpo--message', __( 'Settings Saved', 'foodexpo' ), 'updated' );
                        }
                        //
                        settings_fields( 'foodexpo--settings_option_group' ); 
                        //
                        do_settings_sections( 'foodexpo--settings_option_group' ); 

                        // show error/update messages
                        settings_errors( 'foodexpo--messages' );

                        // Element Section
                        self::section_element(); 
                        ?>
                    </form>
                </div>
            </div>
    		<?php
    	}

        /**
         * Save Button
         *
         *
         */
        private static function save_button() {
            ?>
            <div class="foodexpo--btn-wrapper">
                <button type="submit" class="foodexpo--save-btn"><?php esc_html_e( 'Save Changes', 'foodexpo' ); ?></button>
            </div>
            <?php
        }
        
        /**
         * Section Element
         *
         *
         */
        private static function section_element() {

            $Elements = new Elements_Section();

            $getElements = $Elements->widget_lists();

            ?>
            <section class="tab-content is-active" id="foodexpo--tabs_elements">
                <div class="foodexpo--tab-content-inner clearfix">
                    <div class="foodexpo--tab-content-head clearfix">
                        <div class="foodexpo--tab-content-left foodexpo--float-left">
                            <?php 
                            if( !empty( $Elements->sectionTitle ) ) {
                                echo '<h3 class="foodexpo--title-1">'.esc_html( $Elements->sectionTitle ).'</h3>';
                            }
                            ?>
                            <div class="foodexpo--plugin-enable-disable-menu">
                                <span class="enable" data-btn="enable"><?php esc_html_e( 'Enable All', 'foodexpo' ); ?></span>
                                <span class="disable" data-btn="disable"><?php esc_html_e( 'Disable All', 'foodexpo' ); ?></span>
                            </div>
                        </div>
                        <div class="foodexpo--tab-content-right foodexpo--float-right">
                            <div class="foodexpo--search-form">
                                <div class="foodexpo--search-form-inner">
                                    <input data-search type="text" placeholder="<?php esc_html_e( 'Search...', 'foodexpo' ); ?>">
                                </div>
                            </div>

                            <?php self::save_button(); ?>

                        </div>
                    </div>
 
                    <div class="foodexpo-tab-content-body foodexpo--widgets-switch-area">
                        <div class=" foodexpo--row grid">                                
                                <?php
                                $activation = get_option(FoodExpo_OPTION_NAME);

                                if( !empty( $getElements ) ):
                                    foreach( $getElements as $elements ):

                                        // 
                                        $elementName = $elements['name'];
                                        
                                        $itemWrapperClass ='lite-item';
                                        $checked = '';

                                        //
                                        if( is_array( $activation ) ) {
                                            if( in_array( $elementName , $activation ) ) {
                                                $checked = "checked";
                                            } else {
                                                $checked = "";
                                            }
                                        }
                                ?>
                                <div class="foodexpo--widgets-switch-item foodexpo--col-3 mb-10 <?php echo esc_attr( $itemWrapperClass ); ?>" data-filter-item data-filter-name="<?php echo esc_html( strtolower($elements['label']) ) ?>">
                                    <div class="foodexpo--widgets-switch-item-inner">
                                        
                                        <div class="switch-block widget-switch-title">
                                            <?php 
                                            if( !empty( $elements['label'] ) ) {
                                                echo '<h6>'.esc_html( $elements['label'] ).'</h6>';
                                            }
                                            ?>
                                        </div>
                                        <div class="switch-block foodexpo--float-right">
                                            <div class="switch-inner-block onoffswitch">
                                                <input <?php echo esc_attr( $checked ); ?> type="checkbox" name="foodexpo_widgets[]" class="onoffswitch-checkbox" id="<?php echo esc_attr( $elementName ); ?>" value="<?php echo esc_attr( $elementName ); ?>" >
                                                <label class="onoffswitch-label" for="<?php echo esc_attr( $elementName ); ?>">
                                                    <span class="onoffswitch-inner"></span>
                                                    <span class="onoffswitch-switch"></span>
                                                </label>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <?php 
                                    endforeach;
                                endif;
                                ?>
                        </div>
                    </div>
                </div>
            </section>
            <?php
        }

    }

}