<?php
namespace FoodExpo\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 *
 * Grid Product Menu widget.
 *
 * @since 1.0
 */
class Grid_Menu extends Widget_Base {

	public function get_name() {
		return 'foodexpo-grid-product-menu';
	}

	public function get_title() {
		return esc_html__( 'Grid Product Menu', 'foodexpo' );
	}

	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	public function get_categories() {
		return ['foodexpo-elements'];
	}

	protected function register_controls() {

        // ----------------------------------------  Grid Product Menu content ------------------------------
        $this->start_controls_section(
            'foodexpo_grid_product_settings',
            [
                'label' => esc_html__( 'Grid Product', 'foodexpo' ),
            ]
        );
                
        $this->add_control(
            'grid_product_layout_style',
            [
                'label' => esc_html__( 'Layout Style', 'foodexpo' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => [
                    'style_1' => esc_html__( 'Layout Style 1', 'foodexpo' ),
                    'style_2' => esc_html__( 'Layout Style 2', 'foodexpo' )
                ],
                'default' => 'style_1'
            ]
        );
                
        $this->add_control(
            'grid_column',
            [
                'label' => esc_html__( 'Column', 'foodexpo' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => [
                    '6' => esc_html__( '2 Column', 'foodexpo' ),
                    '4' => esc_html__( '3 Column', 'foodexpo' ),
                    '3' => esc_html__( '4 Column', 'foodexpo' ),
                ],
                'default' => '4'
            ]
        );

        $this->add_control(
            'product_number',
            [
                'label' => esc_html__( 'Product Show Number', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 14,
                'label_block' => false
            ]
        );
        $this->add_control(
            'product_type',
                [
                    'label'     => esc_html__( 'Product Type', 'foodexpo' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => 'recent',
                    'options'   => [
                        'recent'     => esc_html__( 'Recent Products', 'foodexpo'),
                        'featured'   => esc_html__( 'Featured Products', 'foodexpo'),
                        'categories' => esc_html__( 'Categories Products', 'foodexpo' ),
                        'average_rating' => esc_html__( 'Average Rating', 'foodexpo' ),
                    ],
                ]
        );
        $this->add_control(
            'rating',
                [
                    'label'     => esc_html__( 'Rating', 'foodexpo' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => '5',
                    'options'   => [
                        '1'     => esc_html__( '1', 'foodexpo'),
                        '2'     => esc_html__( '2', 'foodexpo'),
                        '3'     => esc_html__( '3', 'foodexpo' ),
                        '4'     => esc_html__( '4', 'foodexpo' ),
                        '5'     => esc_html__( '5', 'foodexpo' ),
                    ],
                    'condition' => [
                        'product_type' => 'average_rating',
                    ]
                ]
        );
        $this->add_control(
            'category',
                [
                    'label'     => esc_html__( 'Categories', 'foodexpo' ),
                    'type'      => Controls_Manager::SELECT2,
                    'multiple'  => true,
                    'default'   => 'recent',
                    'options'   => '',
                    'label_block' => true,
                    'condition' => [
                        'product_type' => 'categories',
                    ]
                ]
        );

        $this->end_controls_section(); // End Accordion content

        /**
         * Style Tab
         * ------------------------------ Grid Style Settings ------------------------------
         *
         */
        $this->start_controls_section(
            'foodexpo_grid_wrapper_settings', [
                'label' => esc_html__( 'Wrapper Area Settings', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'content_wrapper_margin',
            [
                'label' => esc_html__( 'Margin', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-section-grid-product' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'content_wrapper_padding',
            [
                'label' => esc_html__( 'Padding', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-section-grid-product' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'content_wrapper_border',
                'label' => esc_html__( 'Border', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-section-grid-product',
            ]
        );
        $this->add_responsive_control(
            'content_wrapper_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-section-grid-product' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'content_wrapper_shadow',
                'label' => esc_html__( 'Box Shadow', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-section-grid-product',
            ]
        ); 
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'content_wrapper_background',
                'label' => esc_html__( 'Background', 'foodexpo' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .foex-section-grid-product',
            ]
        );
        $this->end_controls_section();

        /**
         * Style Tab
         * ------------------------------ Item Settings ------------------------------
         *
         */
        $this->start_controls_section(
            'foodexpo_grid_item_settings', [
                'label' => esc_html__( 'Item Settings', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_responsive_control(
                'item_area_margin',
                [
                    'label' => esc_html__( 'Margin', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foex-product-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'item_area_padding',
                [
                    'label' => esc_html__( 'Padding', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foex-product-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_group_control(
                \Elementor\Group_Control_Border::get_type(),
                [
                    'name' => 'item_area_border_border',
                    'label' => esc_html__( 'Border', 'foodexpo' ),
                    'selector' => '{{WRAPPER}} .foex-product-item',
                ]
            );
            $this->add_responsive_control(
                'item_area_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foex-product-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                ]
            );
            $this->add_group_control(
                \Elementor\Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'item_area_shadow',
                    'label' => esc_html__( 'Box Shadow', 'foodexpo' ),
                    'selector' => '{{WRAPPER}} .foex-product-item',
                ]
            ); 
            $this->add_group_control(
                \Elementor\Group_Control_Background::get_type(),
                [
                    'name' => 'item_area_background',
                    'label' => esc_html__( 'Background', 'foodexpo' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .foex-product-item',
                ]
            );

        $this->end_controls_section();

        /**
         * Style Tab
         * ------------------------------ Product Title Style Settings ------------------------------
         *
         */
        $this->start_controls_section(
            'foodexpo_product_title_settings', [
                'label' => esc_html__( 'Title', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-title a' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => esc_html__( 'Typography', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-title a',
            ]
        );
        $this->add_responsive_control(
            'title_margin',
            [
                'label' => esc_html__( 'Margin', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );
        $this->add_responsive_control(
            'title_padding',
            [
                'label' => esc_html__( 'Padding', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'title_border',
                'label' => esc_html__( 'Border', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-title',
            ]
        );
        $this->add_responsive_control(
            'title_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'title_bg_color',
                'label' => esc_html__( 'Background', 'foodexpo' ),
                'show_label' => true,
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .foex-product-title',
            ]
        );

        $this->end_controls_section();

        /**
         * Style Tab
         * ------------------------------ Descriptions Style Settings ------------------------------
         *
         */
        
        $this->start_controls_section(
            'foodexpo_product_descriptions_settings', [
                'label' => esc_html__( 'Short Descriptions', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'descriptions_color',
            [
                'label' => esc_html__( 'Text Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-info p' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'descriptions_typography',
                'label' => esc_html__( 'Typography', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-info p',
            ]
        );
        $this->add_responsive_control(
            'descriptions_margin',
            [
                'label' => esc_html__( 'Margin', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-info p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'descriptions_padding',
            [
                'label' => esc_html__( 'Padding', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-info p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'descriptions_border',
                'label' => esc_html__( 'Border', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-info p',
            ]
        );
        $this->add_responsive_control(
            'descriptions_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-info p' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'descriptions_bg_color',
                'label' => esc_html__( 'Background', 'foodexpo' ),
                'show_label' => true,
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .foex-product-info p',
            ]
        );

        $this->end_controls_section();

        /**
         * Style Tab
         * ------------------------------ Price Style Settings ------------------------------
         *
         */
        
        $this->start_controls_section(
            'foodexpo_product_price_settings', [
                'label' => esc_html__( 'Price', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'regular_price_color',
            [
                'label' => esc_html__( 'Regular Price Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price del .woocommerce-Price-amount.amount' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sale_price_color',
            [
                'label' => esc_html__( 'Sale Price Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price .woocommerce-Price-amount.amount' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'price_typography',
                'label' => esc_html__( 'Typography', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-price .woocommerce-Price-amount.amount',
            ]
        );
        $this->add_control(
            'regular_price_font_size',
            [
                'label' => esc_html__( 'Regular Price Font Size', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 100,
                'step' => 1,
                'default' => 10,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price del .woocommerce-Price-amount.amount' => 'font-size: {{VALUE}}px',
                ],
            ]
        );

        $this->add_control(
            'price_lable_color',
            [
                'label' => esc_html__( 'Price Lable Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price strong' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'price_lable_font_size',
            [
                'label' => esc_html__( 'Price Lable Font Size', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 100,
                'step' => 1,
                'default' => 16,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price strong' => 'font-size: {{VALUE}}px',
                ],
            ]
        );

        $this->add_responsive_control(
            'price_margin',
            [
                'label' => esc_html__( 'Margin', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'price_padding',
            [
                'label' => esc_html__( 'Padding', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'price_border',
                'label' => esc_html__( 'Border', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-price',
            ]
        );
        $this->add_responsive_control(
            'price_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'price_bg_color',
                'label' => esc_html__( 'Background', 'foodexpo' ),
                'show_label' => true,
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .foex-product-price',
            ]
        );

        $this->end_controls_section();


        //------------------------------ Image Style ------------------------------
        $this->start_controls_section(
            'product_image_style', [
                'label' => esc_html__( 'Image', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'product_img_margin',
            [
                'label' => esc_html__( 'Margin', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-thumbnail' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'product_padding',
            [
                'label' => esc_html__( 'Padding', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-thumbnail' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'product_border',
                'label' => esc_html__( 'Border', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-thumbnail img',
            ]
        );
        $this->add_responsive_control(
            'product_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-thumbnail img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'product_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-thumbnail img',
            ]
        );

        $this->end_controls_section();



        /**
         * Style Tab
         * ------------------------------  Add Cart btn for Style 1 Settings ------------------------------
         *
         */
        
        $this->start_controls_section(
            'foodexpo_product_cart_icon_style_settings', [
                'label' => esc_html__( 'Add to Cart', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => ['grid_product_layout_style' => 'style_1']
            ]
        );
        $this->add_responsive_control(
            'cart_icon_width',
            [
                'label' => esc_html__( 'Width', 'foodexpo' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '36',
                ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button' => 'width: {{SIZE}}{{UNIT}};'
                ],
            ]
        );
        $this->add_responsive_control(
            'cart_icon_height',
            [
                'label' => esc_html__( 'Height', 'foodexpo' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '36',
                ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button' => 'height: {{SIZE}}{{UNIT}};'
                ],
            ]
        );
        $this->add_control(
            'cart_icon_color',
            [
                'label' => esc_html__( 'Icon Border Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button' => 'border-color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'cart_icon_hover_color',
            [
                'label' => esc_html__( 'Icon Border Hover Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button:hover' => 'border-color: {{VALUE}} !important',
                ],
            ]
        );


        $this->end_controls_section();



        /**
         * Style Tab
         * ------------------------------  Add Cart btn for Style 2 Settings ------------------------------
         *
         */
        
        $this->start_controls_section(
            'foodexpo_product_cart_icon_style_2_settings', [
                'label' => esc_html__( 'Add to Cart Button', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => ['grid_product_layout_style' => 'style_2']
            ]
        );
        $this->add_responsive_control(
            'cart_2_icon_width',
            [
                'label' => esc_html__( 'Width', 'foodexpo' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => '100',
                ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button' => 'width: {{SIZE}}{{UNIT}};'
                ],
            ]
        );
        $this->add_responsive_control(
            'cart_2_icon_height',
            [
                'label' => esc_html__( 'Height', 'foodexpo' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => '100',
                ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button' => 'height: {{SIZE}}{{UNIT}};'
                ],
            ]
        );

        $this->add_responsive_control(
            'cart_2_btn_img_margin',
            [
                'label' => esc_html__( 'Margin', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'cart_2_btn_padding',
            [
                'label' => esc_html__( 'Padding', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'cart_2_btn__border',
                'label' => esc_html__( 'Border', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button',
            ]
        );
        $this->add_responsive_control(
            'cart_2_btn_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foex-product-price-wrap .foex-product-cart-btn a.add_to_cart_button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
               
        
        //
        $this->start_controls_tabs(
            'cart_2_btn_tabs'
        );

        $this->start_controls_tab(
            'cart_2_btn_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'foodexpo' ),
            ]
        );

        $this->add_control(
            'cart_2_text_color',
            [
                'label' => esc_html__( 'Text Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-grid-product-style-2 .foex-product-cart-btn a' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'cart_2_btn_bg_color',
                'label' => esc_html__( 'Background', 'foodexpo' ),
                'show_label' => true,
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .foex-grid-product-style-2 .foex-product-cart-btn a',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'cart_2_btn_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'foodexpo' ),
            ]
        );

        $this->add_control(
            'cart_2_hover_text_color',
            [
                'label' => esc_html__( 'Hover Text Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-grid-product-style-2 .foex-product-cart-btn a:hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'cart_2_icon_hover_border_color',
            [
                'label' => esc_html__( 'Hover Border Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foex-grid-product-style-2 .foex-product-cart-btn a:hover' => 'border-color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'cart_2_btn_hover_bg_color',
                'label' => esc_html__( 'Background', 'foodexpo' ),
                'show_label' => true,
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .foex-grid-product-style-2 .foex-product-cart-btn a:hover',
            ]
        );
        $this->end_controls_tab();

        $this->end_controls_tabs();




        $this->end_controls_section();

	}

	protected function render() {
        // get settings
        $settings = $this->get_settings_for_display();

        if( $settings['grid_product_layout_style'] == 'style_1' ) {
            wc_get_template('grid_product_style_1.php', array( 'settings' => $settings ), '', FOODEXPO_EW_DIR_PATH.DIRECTORY_SEPARATOR.'view'.DIRECTORY_SEPARATOR);
        }

        //
        if( $settings['grid_product_layout_style'] == 'style_2' ) {
            wc_get_template('grid_product_style_2.php', array( 'settings' => $settings ), '', FOODEXPO_EW_DIR_PATH.DIRECTORY_SEPARATOR.'view'.DIRECTORY_SEPARATOR);
        }
       
    }



}
