<?php
namespace FoodExpo\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 *
 * List Tab Product Menu widget.
 *
 * @since 1.0
 */
class Menu_Showcase extends Widget_Base {

	public function get_name() {
		return 'foodexpo-menu-showcase';
	}

	public function get_title() {
		return esc_html__( 'Menu Showcase', 'foodexpo' );
	}

	public function get_icon() {
		return 'eicon-editor-list-ol';
	}

	public function get_categories() {
		return ['foodexpo-elements'];
	}

	protected function register_controls() {

		$repeater = new \Elementor\Repeater();

        // ----------------------------------------  Menu Showcase content ------------------------------
        $this->start_controls_section(
            'foodexpo_menu_showcase_settings',
            [
                'label' => esc_html__( 'Menu Showcase Content', 'foodexpo' )
            ]
        );
        
        $this->add_control(
            'menu_showcase_heading_title',
            [
                'label' => __( 'Heading Title', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );


        $repeater->add_control(
            'menu_showcase_number', [
                'label' => __( 'Number', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '1' , 'foodexpo' ),
                'label_block' => true,
            ]
        );    
        $repeater->add_control(
            'menu_showcase_title', [
                'label' => __( 'Title', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Title' , 'foodexpo' ),
                'label_block' => true,
            ]
        );  
        $repeater->add_control(
            'menu_showcase_price', [
                'label' => __( 'Price', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '',
                'label_block' => true,
            ]
        );

        $this->add_control(
            'menu_showcase_list',
            [
                'label' => __( 'Food Menu Showcase', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ menu_showcase_title }}}',
            ]
        );


        $this->end_controls_section(); // End Menu Showcase content

        /**
         * Style Tab
         * ------------------------------ Menu Showcase Style Settings ------------------------------
         *
         */
        $this->start_controls_section(
            'foodexpo_menu_showcase_wrapper_settings', [
                'label' => esc_html__( 'Wrapper Area Settings', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'content_wrapper_margin',
            [
                'label' => esc_html__( 'Margin', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foodexpo-menu-showcase' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'content_wrapper_padding',
            [
                'label' => esc_html__( 'Padding', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foodexpo-menu-showcase' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'content_wrapper_border',
                'label' => esc_html__( 'Border', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foodexpo-menu-showcase',
            ]
        );
        $this->add_responsive_control(
            'content_wrapper_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                'type' => Controls_Manager::DIMENSIONS,
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .foodexpo-menu-showcase' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'content_wrapper_shadow',
                'label' => esc_html__( 'Box Shadow', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foodexpo-menu-showcase',
            ]
        ); 
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'content_wrapper_background',
                'label' => esc_html__( 'Background', 'foodexpo' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .foodexpo-menu-showcase',
            ]
        );
        $this->end_controls_section();

        /**
         * Style Tab
         * ------------------------------ Menu Showcase Heading Title Settings ------------------------------
         *
         */
        $this->start_controls_section(
            'foodexpo_menu_showcase_heading_title_settings', [
                'label' => esc_html__( 'Heading Title', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'heading_title_color',
                [
                    'label' => esc_html__( 'Title Color', 'foodexpo' ),
                    'type' => \Elementor\Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .foodexpo-menu-showcase-title h3' => 'color: {{VALUE}} !important',
                    ],
                ]
            );
            $this->add_group_control(
                \Elementor\Group_Control_Typography::get_type(),
                [
                    'name' => 'heading_title_typography',
                    'label' => esc_html__( 'Typography', 'foodexpo' ),
                    'selector' => '{{WRAPPER}} .foodexpo-menu-showcase-title h3',
                ]
            );
            $this->add_responsive_control(
                'heading_title_alignment',
                [
                    'type' => \Elementor\Controls_Manager::CHOOSE,
                    'label' => esc_html__( 'Alignment', 'foodexpo' ),
                    'options' => [
                        'left' => [
                            'title' => esc_html__( 'Left', 'foodexpo' ),
                            'icon' => 'eicon-text-align-left',
                        ],
                        'center' => [
                            'title' => esc_html__( 'Center', 'foodexpo' ),
                            'icon' => 'eicon-text-align-center',
                        ],
                        'right' => [
                            'title' => esc_html__( 'Right', 'foodexpo' ),
                            'icon' => 'eicon-text-align-right',
                        ],
                    ],
                    'default' => 'left',
                    'selectors' => [
                        '{{WRAPPER}} .foodexpo-menu-showcase-title h3' => 'text-align: {{VALUE}} !important',
                    ],
                ]
            );
            $this->add_responsive_control(
                'heading_title_margin',
                [
                    'label' => esc_html__( 'Margin', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foodexpo-menu-showcase-title h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'heading_title_padding',
                [
                    'label' => esc_html__( 'Padding', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foodexpo-menu-showcase-title h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_group_control(
                \Elementor\Group_Control_Border::get_type(),
                [
                    'name' => 'heading_title_border',
                    'label' => esc_html__( 'Border', 'foodexpo' ),
                    'selector' => '{{WRAPPER}} .foodexpo-menu-showcase-title h3',
                ]
            );
            $this->add_responsive_control(
                'heading_title_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foodexpo-menu-showcase-title h3' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                ]
            );
            $this->add_group_control(
                \Elementor\Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'heading_title_shadow',
                    'label' => esc_html__( 'Box Shadow', 'foodexpo' ),
                    'selector' => '{{WRAPPER}} .foodexpo-menu-showcase-title h3',
                ]
            ); 
            $this->add_group_control(
                \Elementor\Group_Control_Background::get_type(),
                [
                    'name' => 'heading_title_background',
                    'label' => esc_html__( 'Background', 'foodexpo' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .foodexpo-menu-showcase-title h3',
                ]
            );


        $this->end_controls_section();

        /**
         * Style Tab
         * ------------------------------ Menu Showcase Item Wrapper Settings ------------------------------
         *
         */
        $this->start_controls_section(
            'foodexpo_menu_showcase_item_wrapper_settings', [
                'label' => esc_html__( 'Item Wrapper Settings', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_responsive_control(
                'menu_item_wrapper_margin',
                [
                    'label' => esc_html__( 'Margin', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foodexpo-menu-showcase ul li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'menu_item_wrapper_padding',
                [
                    'label' => esc_html__( 'Padding', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foodexpo-menu-showcase ul li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_group_control(
                \Elementor\Group_Control_Border::get_type(),
                [
                    'name' => 'menu_item_wrapper_border',
                    'label' => esc_html__( 'Border', 'foodexpo' ),
                    'selector' => '{{WRAPPER}} .foodexpo-menu-showcase ul li',
                ]
            );
            $this->add_responsive_control(
                'menu_item_wrapper_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'foodexpo' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'devices' => [ 'desktop', 'tablet', 'mobile' ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .foodexpo-menu-showcase ul li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                ]
            );
            $this->add_group_control(
                \Elementor\Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'menu_item_wrapper_shadow',
                    'label' => esc_html__( 'Box Shadow', 'foodexpo' ),
                    'selector' => '{{WRAPPER}} .foodexpo-menu-showcase ul li',
                ]
            ); 
            $this->add_group_control(
                \Elementor\Group_Control_Background::get_type(),
                [
                    'name' => 'menu_item_wrapper_background',
                    'label' => esc_html__( 'Background', 'foodexpo' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .foodexpo-menu-showcase ul li',
                ]
            );

        $this->end_controls_section();

        /**
         * Style Tab
         * ------------------------------ Menu Showcase Item Style Settings ------------------------------
         *
         */
        $this->start_controls_section(
            'foodexpo_menu_item_style_settings', [
                'label' => esc_html__( 'Item Style', 'foodexpo' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        // serial popover toggle
        $this->add_control(
            'menu_item_serial_popover_toggle',
            [
                'label' => esc_html__( 'Item Serial', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'Default', 'foodexpo' ),
                'label_on' => esc_html__( 'Custom', 'foodexpo' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'menu_item_serial_color',
            [
                'label' => esc_html__( 'Title Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foodexpo-menu-showcase-item-wrap .menu-title-wrap .menu-serial' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'menu_item_serial_typography',
                'label' => esc_html__( 'Typography', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foodexpo-menu-showcase-item-wrap .menu-title-wrap .menu-serial',
            ]
        );
       

        $this->end_popover(); // End serial popover toggle

        // Title popover toggle
        $this->add_control(
            'menu_item_title_popover_toggle',
            [
                'label' => esc_html__( 'Item Title', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'Default', 'foodexpo' ),
                'label_on' => esc_html__( 'Custom', 'foodexpo' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'menu_item_title_color',
            [
                'label' => esc_html__( 'Title Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foodexpo-menu-showcase-item-wrap .menu-title-wrap .menu-title' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'menu_item_title_typography',
                'label' => esc_html__( 'Typography', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foodexpo-menu-showcase-item-wrap .menu-title-wrap .menu-title',
            ]
        );
       

        $this->end_popover(); // End Title popover toggle


        // Dots popover toggle
        $this->add_control(
            'menu_item_dots_popover_toggle',
            [
                'label' => esc_html__( 'Item Dots', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'Default', 'foodexpo' ),
                'label_on' => esc_html__( 'Custom', 'foodexpo' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'menu_item_dot_color',
            [
                'label' => esc_html__( 'Dot Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foodexpo-menu-showcase-item-wrap .dots-line' => 'border-color: {{VALUE}} !important',
                ],
            ]
        );
   

        $this->end_popover(); // End Dots popover toggle


        // Price popover toggle
        $this->add_control(
            'menu_item_price_popover_toggle',
            [
                'label' => esc_html__( 'Item Price', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'label_off' => esc_html__( 'Default', 'foodexpo' ),
                'label_on' => esc_html__( 'Custom', 'foodexpo' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_control(
            'menu_item_price_color',
            [
                'label' => esc_html__( 'Color', 'foodexpo' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .foodexpo-menu-showcase-item-wrap .menu-item-price' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'menu_item_price_typography',
                'label' => esc_html__( 'Typography', 'foodexpo' ),
                'selector' => '{{WRAPPER}} .foodexpo-menu-showcase-item-wrap .menu-item-price',
            ]
        );
       

        $this->end_popover(); // End Price popover toggle




        
        $this->end_controls_section();

        

	}

	protected function render() {
        // get settings
        $settings = $this->get_settings_for_display();

        echo '<div class="foodexpo-menu-showcase">';

        if( !empty( $settings['menu_showcase_heading_title'] ) ) {
            echo '<div class="foodexpo-menu-showcase-title">';
                echo '<h3>'.esc_html( $settings['menu_showcase_heading_title'] ).'</h3>';
            echo '</div>';
        }

        echo '<ul>';

            if( !empty( $settings['menu_showcase_list'] ) ) {

                foreach( $settings['menu_showcase_list'] as $list ) {

                    echo '<li class="foodexpo-menu-showcase-item-wrap">
                    <div class="menu-title-wrap">
                    <div class="menu-serial">'.esc_html( $list['menu_showcase_number'] ?? '' ).'</div>
                    <div class="menu-title">'.esc_html( $list['menu_showcase_title'] ?? '' ).'</div>
                    </div>

                    <div class="dots-line"></div>
                    <div class="menu-item-price">'.esc_html( $list['menu_showcase_price'] ?? '' ).'</div>
                  
                    </li>';

                }

            }

        echo '</ul>';
        echo '</div>';

    }



}
